package com.ekingwin.bas.cloud.dataDictionary.service.impl;

import com.ekingwin.bas.cloud.dataDictionary.dao.AppVersionMapper;
import com.ekingwin.bas.cloud.dataDictionary.dao.DataDictionaryDao;
import com.ekingwin.bas.cloud.dataDictionary.dao.DataDictionaryOptionDao;
import com.ekingwin.bas.cloud.dataDictionary.dao.entity.DataDictionaryOption;
import com.ekingwin.bas.cloud.dataDictionary.dto.*;
import com.ekingwin.bas.cloud.dataDictionary.service.IDataDictionaryOptionService;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.service.BaseService;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;

@Primary
@Service
public class DataDictionaryOptionServiceImpl extends BaseService implements IDataDictionaryOptionService {
	@Autowired
	private DataDictionaryDao dataDictionaryDao;
	@Autowired
	private DataDictionaryOptionDao dao;

	@Autowired
	private AppVersionMapper appVersionMapper;

	@Override
	public boolean save(DataDictionaryOptionDto object) throws BasException {
		if (null != object && object.getId() != null) {
			DataDictionaryOption record = new DataDictionaryOption();
			this.buildEntity(record, object);
			dao.updateByPrimaryKeySelective(record);
		} else {
			save(object, DataDictionaryOption.class, dao);
		}
		return false;
	}

	@Override
	public boolean delete(String id) throws BasException {
		dao.deleteByPrimaryKey(id);
		return false;
	}

	@Override
	public PageCriteria<DataDictionaryOptionDto> query(QueryDTO query) throws BasException {
		try {
			Example example = buildQuery(query, DataDictionaryOption.class);
			return query(query, () -> dao.selectByExample(example), DataDictionaryOptionDto.class);
		} catch (BasException e) {
			log.error(e.getMessage(), e);
			throw new BasException(e);
		}
	}

	public List<DataDictionaryOption> queryOptionByDicId(String dictionaryId) throws BasException {
		return dataDictionaryDao.queryOptionByDicId(dictionaryId);
	}

	@Override
	public DataDictionaryOptionDto get(String id) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<DataDictionaryOptionDto> getByDictionaryen(String dictionaryen) throws BasException {
		List<DataDictionaryOptionDto> result = new ArrayList<DataDictionaryOptionDto>();
		List<DataDictionaryOption> dataDictionaryOptionList = dataDictionaryDao.getByDictionaryen(dictionaryen);
		for (int i = 0; i < dataDictionaryOptionList.size(); i++) {
			DataDictionaryOptionDto dataDictionaryOptionDto = new DataDictionaryOptionDto();
			try {
				super.commonBuild(dataDictionaryOptionDto, dataDictionaryOptionList.get(i));
				result.add(dataDictionaryOptionDto);
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return result;
	}

	@Override
	public void saveOptions(DataDictionaryDto dataDictionaryDto) throws BasException {
		List<DataDictionaryOptionDto> optionlist = dataDictionaryDto.getOptionlist();
		if (dataDictionaryDto.getId() != null) {//修改
			dataDictionaryDto.setUpdateon(new Date());
			dataDictionaryDao.updateDic(dataDictionaryDto);
		}else{
			dataDictionaryDto.setCreateon(new Date());
			dataDictionaryDto.setId(UUID.randomUUID().toString());
			dataDictionaryDao.insertDic(dataDictionaryDto);
		}
		dataDictionaryDao.deleteDicOption(dataDictionaryDto.getId());

			for (int i = 0; i < optionlist.size(); i++) {
				if (optionlist.get(i).getPid() == null) {
					optionlist.get(i).setPid(dataDictionaryDto.getId());
				}
				optionlist.get(i).setId(UUID.randomUUID().toString());
				optionlist.get(i).setCreateon(new Date());
				dataDictionaryDao.insertDicOption(optionlist.get(i));
			}

	}

	@Override
	public boolean deleteByPid(String pid) throws BasException {
		dataDictionaryDao.deleteOptionsByPid(pid);
		return false;
	}

	@Override
	public List<DataDictionaryOptionDto> getByDictionaryenAndOptionValue(String dictionaryen, String value)
			throws BasException {
		List<DataDictionaryOptionDto> result = new ArrayList<DataDictionaryOptionDto>();
		List<DataDictionaryOption> dataDictionaryOptionList = dataDictionaryDao
				.getByDictionaryenAndOptionValue(dictionaryen, value);
		for (int i = 0; i < dataDictionaryOptionList.size(); i++) {
			DataDictionaryOptionDto dataDictionaryOptionDto = new DataDictionaryOptionDto();
			try {
				super.commonBuild(dataDictionaryOptionDto, dataDictionaryOptionList.get(i));
				result.add(dataDictionaryOptionDto);
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return result;
	}

	@Override
	public String getOptionTextByValue(List<DataDictionaryOptionDto> dataDictionaryOptionDtoList, String value)
			throws BasException {
		String result = null;
		if (dataDictionaryOptionDtoList.size() > 0 && value != null) {
			for (int i = 0; i < dataDictionaryOptionDtoList.size(); i++) {
				if (value.equals(dataDictionaryOptionDtoList.get(i).getValue())) {
					result = dataDictionaryOptionDtoList.get(i).getText();
				}
			}
		}
		return result;
	}

	@Override
	public boolean addOptions(DataDictionaryDto dataDictionaryDto) throws BasException {
		List<DataDictionaryOptionDto> optionlist = dataDictionaryDto.getOptionlist();
		if (optionlist != null) {
			for (int i = 0; i < optionlist.size(); i++) {
				if (dataDictionaryDto.getId() != null && optionlist.get(i).getPid() == null) {
					optionlist.get(i).setPid(dataDictionaryDto.getId());
				}
				save(optionlist.get(i));
			}
		}
		return false;
	}

	private void buildEntity(Object dest, Object src) {
		try {
			super.commonBuild(dest, src);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void buildDTO(Object dest, Object src) {
		try {
			super.commonBuild(dest, src);

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 根据模块和名称获取数据字典
	 * @param dataDictionaryDto
	 * @return
	 */
	public   List<DataDictionaryVo> getByDictionaryenAndModel(DataDictionaryDto  dataDictionaryDto){

		return  dataDictionaryDao.getByDictionaryenAndModel(dataDictionaryDto);
	}

	/**
	* 获取app版本号
	* @Param:  * @param phoneType
	* @return: com.ekingwin.bas.cloud.dataDictionary.dto.AppVersionVo
	* @Author: zhangjie
	* @Date: 2019/11/5 15:17
	*/
	@Override
	public AppVersionVo getAppVersion(AppVersionDto appVersionDto){
		String appArea = appVersionDto.getAppArea();
		if (StringUtils.isEmpty(appArea)){
			appArea="E0103";
		}
		appVersionDto.setAppArea(appArea );
		AppVersionVo appVersionVo=appVersionMapper.getAppVersionDown(appVersionDto);
		return  appVersionVo;
	}
}
