package com.ekingwin.bas.cloud.dataDictionary.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import com.ekingwin.bas.cloud.dataDictionary.dao.DataDictionaryDao;
import com.ekingwin.bas.cloud.dataDictionary.dao.DataDictionaryOptionDao;
import com.ekingwin.bas.cloud.dataDictionary.dao.entity.DataDictionary;
import com.ekingwin.bas.cloud.dataDictionary.dao.entity.DataDictionaryOption;
import com.ekingwin.bas.cloud.dataDictionary.dto.DataDictionaryDto;
import com.ekingwin.bas.cloud.dataDictionary.dto.DataDictionaryOptionDto;
import com.ekingwin.bas.cloud.dataDictionary.service.IDataDictionaryOptionService;
import com.ekingwin.bas.cloud.dataDictionary.service.IDataDictionaryService;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.service.BaseService;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import tk.mybatis.mapper.entity.Example;

@Primary
@Service
public class DataDictionaryServiceImpl extends BaseService implements IDataDictionaryService {

	@Autowired
	private DataDictionaryDao dao;
	@Autowired
	private IDataDictionaryOptionService dataDictionaryOptionServiceImpl;

	@Override
	public boolean save(DataDictionaryDto object) throws BasException {
		if (null != object && object.getId() != null) {
			DataDictionary record = new DataDictionary();
			this.buildEntity(record, object);
			dao.updateByPrimaryKeySelective(record);
		} else {
			save(object, DataDictionary.class, dao);
		}
		List<DataDictionaryOptionDto> list = object.getOptionlist();
		if (null != list && list.size() > 0) {
			for (DataDictionaryOptionDto dto : list) {
				dto.setPid(object.getId());
				dataDictionaryOptionServiceImpl.save(dto);
			}
		}
		return false;
	}

	@Override
	public boolean delete(String id) throws BasException {
		if (id != null && id.contains(",")) {
			String[] ids = id.split(",");
			for (int i = 0; i < ids.length; i++) {
				dao.deleteByPrimaryKey(ids[i]);
			}
		} else {
			dao.deleteByPrimaryKey(id);
		}
		return false;
	}

	@Override
	public PageCriteria<DataDictionaryDto> query(QueryDTO query) throws BasException {
		try {
			Example example = buildQuery(query, DataDictionary.class);
			return query(query, () -> dao.selectByExample(example), DataDictionaryDto.class);
		} catch (BasException e) {
			log.error(e.getMessage(), e);
			throw new BasException(e);
		}
	}

	@Override
	public DataDictionaryDto get(String id) throws BasException {
		try {
			DataDictionaryDto linkDto = get(DataDictionaryDto.class, id, dao);
			List<DataDictionaryOption> list = dao.queryOptionByDicId(id);
			List<DataDictionaryOptionDto> listDto = new ArrayList<>();
			if(null!=list&&list.size()>0) {
				for(DataDictionaryOption op:list) {
					DataDictionaryOptionDto dto = new DataDictionaryOptionDto();
					this.buildDTO(dto, op);
					listDto.add(dto);
				}
			}
			linkDto.setOptionlist(listDto);
			return linkDto;
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			throw new BasException(e.getMessage(), e);
		}
	}

	private void buildEntity(Object dest, Object src) {
		try {
			super.commonBuild(dest, src);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void buildDTO(Object dest, Object src) {
		try {
			super.commonBuild(dest, src);

		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
