package com.ekingwin.bas.cloud.document.service.impl;

import java.io.File;
import java.io.InputStream;
import java.util.Map;
import java.util.UUID;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import com.ekingwin.bas.cloud.document.UAttachementException;
import com.ekingwin.bas.cloud.document.config.AttachDefineConfig;
import com.ekingwin.bas.cloud.document.dto.UploadFileDto;
import com.ekingwin.bas.cloud.document.dto.UploadUserDto;
import com.ekingwin.bas.cloud.document.model.DocModel;
import com.ekingwin.bas.cloud.document.service.IDocService;
import com.ekingwin.bas.cloud.document.service.IIUploaderService;
import com.ekingwin.bas.cloud.document.service.IUserService;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.utils.file.FileUtils;
import com.ekingwin.bas.cloud.infra.utils.web.UserUtils;

@Service(value = "commonUploaderService")
public class CommonUploaderServiceImpl implements IIUploaderService{

	private Logger logger = LoggerFactory.getLogger(this.getClass());
	
	
	@Autowired
	private IDocService docService;
	@Autowired
	@Qualifier(value = "userServiceImpl")
	private IUserService userManager;

	@Autowired
	private AttachDefineConfig config;
	
	//上传文件
	@Override
	public UploadFileDto upload(File file, String fileName, Map<String, String[]> fileMeta) throws UAttachementException {		
		UploadFileDto uf = new UploadFileDto();
		try {
			
			//初始化文件对象
			DocModel docModel = new DocModel();
			
			UploadUserDto user = getCurrentUser();
			
			//获取文档ID（该ID来源于页面，用于判断上传的文档是否在系统中已经存在，如果存在，则做更新操作）
			String dID = "";
			if(fileMeta.get("dId") != null){
				if(fileMeta.get("dId").length > 0){
					dID = fileMeta.get("dId")[0];
				}
			}
			String updateVer ="";
			if(fileMeta.get("updateVer") != null&&fileMeta.get("updateVer").length > 0){
				updateVer =fileMeta.get("updateVer")[0];
			}
			if(!StringUtils.isEmpty(dID) && !"true".equals(updateVer)){
				//如果文档ID不为空，则更新文档
				docModel = docService.getDocModelBydID(user, dID);
				docModel.setPrimaryFile(file.getPath());
				docModel = docService.updataDocModel(user, docModel);
			}else if(!StringUtils.isEmpty(dID) && "true".equals(updateVer)){
				String oldId=fileMeta.get("updateId")[0];
				String oldName=fileMeta.get("updateName")[0];
				docModel = new DocModel();
				docModel.setPrimaryFile(file.getPath());
				docModel.setDocId(oldId);
				docModel.setDocTitle(fileName);
				docModel.setOriginalName(fileName);
				docModel.setDocName(oldName);
				docModel = docService.updataNewRevDocModel(user, docModel);
			}else{
				//如果文档ID为空，则检入新文档
				docModel.setDocTitle(fileName);
				docModel.setOriginalName(fileName);
				if(fileMeta.get("folderName")!=null){
					docModel.setFolderId(fileMeta.get("folderName")[0]);
				}
				docModel.setPrimaryFile(file.getPath());
				docModel = docService.checkIn(user, docModel);
			}
			
			//封装UploadFile对象，用于返回
			uf.setId(docModel.getDocId());
			uf.setNewName(docModel.getDocTitle());
			uf.setOldName(fileName);
			uf.setSize(file.length());
			uf.setViewUrl(docModel.getWebUrl());
			uf.setDownloadUrl(config.getBaseDownloadUrl() + docModel.getDocId());
			uf.setRevId(docModel.getRevId());
		} catch (Exception e) {
			logger.info("上传文件失败", e);
			throw new UAttachementException(e.getMessage());
		}finally{
			file.delete();
		}
		return uf;
	}
	
	@Override
	public UploadFileDto upload(InputStream inputStream, String fileName,
			Map<String, String[]> fileMeta) throws UAttachementException {

		String path = System.getProperty("user.dir");
		String fileGuid = UUID.randomUUID().toString();
		File file = new File(path + "\\" + fileGuid + ".tmp");
		try {
			FileUtils.inputStreamToFile(inputStream, file);
		} catch (Exception e) {
			logger.info("上传文件失败", e);
			throw new UAttachementException(e.getMessage());
		}
		
		return this.upload(file, fileName, fileMeta);
	}

	private UploadUserDto getCurrentUser() throws UAttachementException{
		UploadUserDto user = null;
		try {
			String userid=UserUtils.getCurrentUser();
			if(StringUtils.isEmpty(userid)) {
				userid="panxl";
			}
			user = userManager.get(userid);
		} catch (BasException e) {
			logger.error(e.getMessage(), e);
			throw new UAttachementException(e);
		}
		return user;
	}

}
