package com.ekingwin.bas.cloud.org.service.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.service.BaseService;
import com.ekingwin.bas.cloud.infra.utils.common.ResultUtils;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.infra.utils.web.UserUtils;
import com.ekingwin.bas.cloud.org.OrganizationException;
import com.ekingwin.bas.cloud.org.dao.IOrganizationUserDao;
import com.ekingwin.bas.cloud.org.dao.entity.Organization;
import com.ekingwin.bas.cloud.org.dto.OrganizationDto;
import com.ekingwin.bas.cloud.org.dto.OrganizationUserDto;
import com.ekingwin.bas.cloud.org.service.IOrganizationService;
import com.ekingwin.bas.cloud.org.service.IOrganizationUserService;
import com.ekingwin.bas.cloud.org.service.IOrganizationUserTenantService;
import com.ekingwin.bas.cloud.user.UserException;
import com.ekingwin.bas.cloud.user.dao.entity.User;
import com.ekingwin.bas.cloud.user.dto.UserDto;

import net.sf.json.JSON;
import net.sf.json.JSONObject;
import tk.mybatis.mapper.entity.Example;

@Service
@Primary
public class OrganizationUserTenantServiceImpl extends BaseService implements IOrganizationUserTenantService {

	@Autowired
	@Qualifier(value="organizationUserServiceImpl")
	private IOrganizationUserService orgUserSer;
	

	@Autowired
	private IOrganizationUserDao orgUserDao;
	
	@Autowired
	private IOrganizationService orgService;

	
	@Override
	public BaseResult<OrganizationUserDto> save(OrganizationUserDto organizationUserDto) throws BasException {
		try {
			BaseResult<OrganizationUserDto> result = null;
			String orgid = organizationUserDto.getOrgid();
			String userid = organizationUserDto.getUserid();
			List<Organization>  listtype = orgUserDao.getTypeByOrgid(orgid);			
			for(Organization type : listtype) {
				String orgtype = type.getType();
				if ("3".equals(orgtype)) {
					List<Map<String, Object>> listuser = orgUserDao.getOrgByUserid(userid,orgid);
					if(listuser.size()== 0) {
							orgUserSer.save(organizationUserDto);
						}else {
							throw new BasException("同一个人员在同一个岗位只能设置一次！");
						}				
				} else {
					throw new BasException("只有岗位可以设置人员！");				
					}	
			}
			return result;
		} catch (Exception e) {
			throw new BasException(e.getMessage());
		}
	}

	@Override
	public BaseResult<OrganizationUserDto> deleteUser(OrganizationUserDto orguser) throws BasException {
		try {
			String orgid = orguser.getOrgid();
			String userid = orguser.getUserid();
			orgUserDao.deleteUserOrg(userid,orgid);
			return ResultUtils.build();
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			throw new OrganizationException(e);
		}
	}

	@Override
	public BaseResult<PageCriteria<UserDto>> getTenantUser(QueryDTO query) throws BasException {
		try {
			String currentUserId = UserUtils.getCurrentUser();
			String orgid = query.getAttr().get("orgid");
			Example example = buildQuery(query, User.class);
			PageCriteria<UserDto>	result = query(query, () -> orgUserDao.selectUsersByEmpuid(example, currentUserId, orgid),
					UserDto.class,(Object dest, Object src) -> this.buildDTO(dest, src));
			return ResultUtils.build(result);
		} catch (BasException e) {
			log.error(e.getMessage(), e);
			throw new UserException(e);
		}
	}
	
	private void buildDTO(Object dest, Object src) {
		try {
			UserDto userdto = (UserDto) dest;
			super.commonBuild(dest, src);

			OrganizationDto org = orgService.getUserDept(userdto.getEmpuid());
			if (org != null) {
				userdto.setDeptid(org.getId());
				userdto.setDeptname(org.getName());
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	
	@Override
	public BaseResult<PageCriteria<OrganizationUserDto>> query(QueryDTO query) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public BaseResult<OrganizationUserDto> get(String id) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public BaseResult<OrganizationUserDto> delete(String id) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

}
