package com.ekingwin.bas.cloud.org.web;

import io.swagger.annotations.Api;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.dto.SaveResultDTO;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.infra.utils.web.UserUtils;
import com.ekingwin.bas.cloud.infra.web.BaseController;
import com.ekingwin.bas.cloud.org.OrganizationException;
import com.ekingwin.bas.cloud.org.dto.OrganizationAuthorityDto;
import com.ekingwin.bas.cloud.org.service.IOrganizationAuthorityService;



@RestController
@RequestMapping("/org/authority")
@Api("用户postController相关api")
public class OrgAuthorityController extends BaseController{
	@Autowired
	@Qualifier(value="organizationAuthorityServiceImpl")
	private IOrganizationAuthorityService orgAutService;
	
	/**
	 * 查询权限
	 * @param query
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value = "/query", method = RequestMethod.POST)
	public PageCriteria<OrganizationAuthorityDto> query(@RequestBody(required = false) QueryDTO query) throws Exception {
		String userid = query.getAttr().get("logid");
		String str = query.getAttr().get("flag");
		int flag;
		if (StringUtils.isEmpty(userid)) {
			userid = UserUtils.getCurrentUser();
		}
		
		if (StringUtils.isEmpty(str.trim())) {
			flag=0;
		}else{
			flag=Integer.parseInt(str);
		}
		
		return orgAutService.getOrgAutByUser(query,userid,flag);
	}
	
	/**
	 * 保存权限
	 * @param postDto
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value = "/save", method = RequestMethod.POST)
	public SaveResultDTO save(@RequestBody OrganizationAuthorityDto orgAutDto) {
		SaveResultDTO result = new SaveResultDTO();
		try {
			orgAutService.saveAll(orgAutDto);
			result.setResult("1");
			result.setMessage(null);
		} catch (OrganizationException e) {
			result.setResult("0");
			result.setMessage(e.getMessage());
		}
		return result;
	}
	

	
	/**
	 * 根据id删除权限
	 * @param Id
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value = "/delete/{Id}", method = RequestMethod.DELETE)
	public SaveResultDTO delete(@PathVariable(value = "Id")String Id) throws Exception {
		SaveResultDTO result = new SaveResultDTO();
		try {
			orgAutService.delete(Id);
			result.setResult("1");
			result.setMessage(Id);
		} catch (OrganizationException e) {
			result.setResult("0");
			result.setMessage(e.getMessage());
		}
		return result;
	}
	
	/**
	 * 根据id查询权限
	 * @param Id
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value = "/get/{id}", method = RequestMethod.GET)
	public OrganizationAuthorityDto get(@PathVariable(value = "id")String Id) throws Exception {
		return orgAutService.get(Id);
	}

}
