package com.ekingwin.bas.cloud.thirdinterface.orgsync.web;

import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.org.dao.entity.Organization;
import com.ekingwin.bas.cloud.org.dao.entity.OrganizationUser;
import com.ekingwin.bas.cloud.org.dto.OrgDto;
import com.ekingwin.bas.cloud.org.dto.OrganizationDto;
import com.ekingwin.bas.cloud.org.service.IOrgService;
import com.ekingwin.bas.cloud.org.service.IOrganizationService;
import com.ekingwin.bas.cloud.org.service.IOrganizationTreeService;
import com.ekingwin.bas.cloud.org.service.IOrganizationUserService;
import com.ekingwin.bas.cloud.thirdinterface.orgsync.dto.*;
import com.ekingwin.bas.cloud.thirdinterface.orgsync.service.IOrgMetaService;
import com.ekingwin.bas.cloud.thirdinterface.orgsync.service.ISyncOrgService;
import com.ekingwin.bas.cloud.thirdinterface.user.dto.ResponseUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Created by liuch 同步HR的组织机构数据（目前代码是同步通威的接口）
 */
@RestController
@RequestMapping("/syncOrg")
@Api("组织orgController相关增删改查的基本方法api")
public class SyncOrgController {

	private Logger logger = LoggerFactory.getLogger(SyncOrgController.class);


	@Autowired
	private RestTemplate restTemplate;
	@Autowired
	@Qualifier(value = "syncOrgServiceImpl")
	private ISyncOrgService syncorgservice;
	@Autowired
	@Qualifier(value = "organizationServiceImpl")
	private IOrganizationService orgService;

	@Autowired
	private IOrganizationUserService orgUserSer;

	@Autowired
	@Qualifier(value = "organizationTreeServiceImpl")
	private IOrganizationTreeService orgTreeSer;
	@Autowired
	@Qualifier(value = "orgServiceImpl")
	private IOrgService orgSer;
	@Autowired
	@Qualifier(value = "orgMetaServiceImpl")
	private IOrgMetaService orgMetaService;

	int pageSize = 1000;

	@RequestMapping(value = "/syncDept", method = RequestMethod.POST)
	public BaseResult syncDept() throws Exception {
		// 获取部门的数量
		List<Organization> updateList = new ArrayList<Organization>();
		List<Organization> insertList = new ArrayList<Organization>();
		int count = syncorgservice.getDeptCount();
		logger.info(String.valueOf(count));
		for (int i = 1; i <= count; i = i + pageSize) {
			DeptList detplist = syncorgservice.getDeptList(i, i + pageSize - 1);
			for (DeptItem item : detplist.getDEPTITEM()) {
				// 获取当前的code是否已经存在数据
				String type = "0";
				String depttype = item.getTW_DEPT_TYPE();
				if (depttype.equals("110") || depttype.equals("130") || depttype.equals("140") || depttype.equals("150")
						|| depttype.equals("240") || depttype.equals("180") || depttype.equals("250")) {//去掉230
					type = "1";
				} else if (depttype.equals("120")) {
					type = "5";
				} else {
					type = "2";
				}
				if (item.getDEPTID().equals("10000000")) {
					type = "0";
				}
				OrganizationDto orgdto = new OrganizationDto();
				orgdto.setName(item.getDESCR());
				orgdto.setEnname(item.getDESCRSHORT());
				orgdto.setCode(item.getDEPTID());
				orgdto.setType(type);
				orgdto.setOthersystemid(item.getDEPTID());
				if (item.getEFF_STATUS().equals("A")) {
					orgdto.setIsdelete("N");
				} else {
					orgdto.setIsdelete("Y");
				}
				orgdto.setPcode(item.getTW_UP_DEPTID());
				orgdto.setUpdatetime(new Date());
				orgdto.setHrtype(item.getTW_DEPT_TYPE());
				// orgService.syncOrg(orgdto);
				Organization newOrg = orgService.getNewOrg(orgdto);
				if (null != newOrg.getId()) {
					updateList.add(newOrg);
				} else {
					insertList.add(newOrg);
				}
			}
			if (updateList.size() > 0) {
				orgService.batchUpdate(updateList);
				updateList.clear();
			}
			if (insertList.size() > 0) {
				orgService.batchInsert(insertList);
				insertList.clear();
			}
		}
		return null;

	}

	@RequestMapping(value = "/syncUser", method = RequestMethod.POST)
	public BaseResult syncUser() throws Exception {
		List<Organization> updateList = new ArrayList<Organization>();
		List<Organization> insertList = new ArrayList<Organization>();
		List<OrganizationUser> updateList1 = new ArrayList<OrganizationUser>();
		List<OrganizationUser> insertList1 = new ArrayList<OrganizationUser>();
		// 获取部门的数量
		int count = syncorgservice.getPersonCount();
		logger.info(String.valueOf(count));
		Long start = System.currentTimeMillis();
		for (int i = 1; i <= count; i = i + pageSize) {
			PersonList personlist = syncorgservice.getPersonList(i, i + pageSize - 1);
			for (PersonItem item : personlist.getPERSONITEM()) {

				// 更新岗位信息
				OrganizationDto orgdto = new OrganizationDto();
				orgdto.setName(item.getDESCR4());
				orgdto.setEnname(item.getDESCR5());
				orgdto.setCode("P" + item.getPOSITION_NBR());
				orgdto.setType("3");
				orgdto.setOthersystemid(item.getPOSITION_NBR());
				if (item.getHR_STATUS().equals("A")) {
					orgdto.setIsdelete("N");
				} else {
					orgdto.setIsdelete("Y");
				}
				orgdto.setPcode(item.getDEPTID());
				orgdto.setUpdatetime(new Date());
				orgdto.setHrtype(item.getJOBCODE());
				// BaseResult<OrganizationDto> orgreturn = orgService.syncOrg(orgdto);
				Organization newOrg = orgService.getNewOrg(orgdto);
				if (null != newOrg.getId()) {
					updateList.add(newOrg);
				} else {
					insertList.add(newOrg);
				}
				// 插入用户岗位表
				// orgUserSer.insertOrupdate(item.getEMPLID(),
				// orgdto.getId(),item.getJOB_INDICATOR());
				OrganizationUser organizationUser = orgUserSer.getOrganizationUser(item.getEMPLID(), orgdto.getId(),
						item.getJOB_INDICATOR());
				if (StringUtils.isNotEmpty(organizationUser.getUserid())
						&& StringUtils.isNotEmpty(organizationUser.getOrgid())) {
					if (organizationUser.getId() != null) {
						updateList1.add(organizationUser);
					} else {
						insertList1.add(organizationUser);
					}
				}
			}
			if (updateList1.size() > 0) {
				orgUserSer.batchUpdate(updateList1);
				updateList1.clear();
			}
			if (insertList1.size() > 0) {
				orgUserSer.batchInsert(insertList1);
				insertList1.clear();
			}
			if (updateList.size() > 0) {
				orgService.batchUpdate(updateList);
				updateList.clear();
			}
			if (insertList.size() > 0) {
				orgService.batchInsert(insertList);
				insertList.clear();
			}
		}
		Long end = System.currentTimeMillis();
		logger.info(String.valueOf((end - start) / 1000));
		// 根据组织表的数据，插入到tree表
		orgTreeSer.insertTreeByOrg();
		// 生成treecode
		orgTreeSer.genTreecode();

		return null;

	}


	@RequestMapping(value = "/createOrg", method = RequestMethod.POST)
	@ApiOperation("创建组织")
	public ResponseOrg createOrg(@RequestBody(required = true) AddOrgAccountParamDto orgParamDto) throws Exception {
		ResponseOrg responseOrg =new ResponseOrg();
		try {
			OrgDto orgDto = orgParamDto.getOrgparmsDto().getOrgDto();
			orgSer.save(orgDto);
			responseOrg.setErrorcode("0");
			responseOrg.setErrorinfo("组织添加成功");
			orgSer.save(orgDto);
		} catch (Exception e) {
			e.printStackTrace();
			responseOrg.setErrorcode("1");
			responseOrg.setErrorinfo("未知的程序异常(业务系统逻辑错误，请联系业务系统管理员)");
		}
		return responseOrg;
	}

	@RequestMapping(value = "/modifyOrg", method = RequestMethod.POST)
	@ApiOperation("修改组织信息")
	public ResponseOrg modifyOrg(@RequestBody(required = true) ModifyOrgAccountParamDto orgParamDto) throws Exception {
		ResponseOrg responseOrg =new ResponseOrg();
		try {
			OrgDto orgDto = orgParamDto.getOrgparmsDto().getOrgDto();
			BaseResult<OrgDto> resultOrg = orgSer.get(orgDto.getId().toLowerCase());
			if(resultOrg.getData()!=null){
				responseOrg.setErrorcode("0");
				responseOrg.setErrorinfo("修改组织成功");
				orgSer.save(orgDto);
			}else{
				responseOrg.setErrorcode("1");
				responseOrg.setErrorinfo("组织不存在");
			}
		} catch (Exception e) {
			e.printStackTrace();
			responseOrg.setErrorcode("1");
			responseOrg.setErrorinfo("未知的程序异常(业务系统逻辑错误，请联系业务系统管理员)");
		}
		return responseOrg;
	}

	@RequestMapping(value = "/disableOrg", method = RequestMethod.POST)
	@ApiOperation("禁用组织")
	public ResponseOrg disableOrg(@RequestBody(required = true) DisableOrgParamDto orgParamDto) throws Exception {
		ResponseOrg responseOrg =new ResponseOrg();
		try {
			List<OrgIdDto>  orgDtoList=orgParamDto.getOrgParmdto().getOrgIdList();
			for(OrgIdDto orgDto : orgDtoList) {
				orgMetaService.disableOrgAccount(orgDto.getId());
			}
			responseOrg.setErrorcode("0");
			responseOrg.setMessage("组织禁用成功");
		} catch (Exception e) {
			e.printStackTrace();
			responseOrg.setErrorcode("1");
			responseOrg.setErrorinfo("未知的程序异常(业务系统逻辑错误，请联系业务系统管理员)");
		}
		return responseOrg;
	}

	@RequestMapping(value = "/enableOrg", method = RequestMethod.POST)
	@ApiOperation("启用组织")
	public ResponseUser enableOrg(@RequestBody(required = true) EnableOrgAccountParamDto enableOrgParamDto) throws Exception {
		ResponseUser responseOrg =new ResponseUser();
		try {
			List<OrgIdDto>  orgDtoList=enableOrgParamDto.getEnableorgparmsDto().getOrgIdDtoList();
			for(OrgIdDto loginDto : orgDtoList) {
				BaseResult<OrgDto> resultOrg = orgSer.get(loginDto.getId().toLowerCase());
				if(resultOrg.getData()!=null){
					orgMetaService.enableOrgAccount(loginDto.getId());
					responseOrg.setErrorcode("0");
					responseOrg.setMessage("启用组织成功");
				}else{
					responseOrg.setErrorcode("1");
					responseOrg.setMessage("组织不存在");
				}
			}

		} catch (Exception e) {
			e.printStackTrace();
			responseOrg.setErrorcode("1");
			responseOrg.setErrorinfo("未知的程序异常(业务系统逻辑错误，请联系业务系统管理员)");
		}
		return responseOrg;
	}

}
