package com.ekingwin.bas.cloud.user.service;

import com.ekingwin.bas.cloud.attachment.dto.FileObject;
import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.dto.SaveResultDTO;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.service.IBaseCurdService;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.org.dto.OrganizationDto;
import com.ekingwin.bas.cloud.user.UserException;
import com.ekingwin.bas.cloud.user.dao.entity.User;
import com.ekingwin.bas.cloud.user.dto.*;
import com.github.pagehelper.PageInfo;

import java.io.InputStream;
import java.util.List;
import java.util.Map;

/**
 * 定义用户基本信息以及其操作的接口，包括了对于用户的基本增删改查的操作
 * @author chenjb
 *
 */
public interface IUserMetaService extends IBaseCurdService<UserDto> {
	public FileObject exportsUser(QueryDTO query) throws UserException;
	public FileObject importsUser(InputStream in) throws UserException;
	public PageCriteria<UserDto> queryUsersInOrg(QueryDTO query) throws UserException;
	public PageCriteria<UserDto> getUsersByNotBen(QueryDTO query) throws UserException;
	public PageCriteria<UserDto> getParentUserById(QueryDTO query) throws UserException;
	public PageCriteria<UserDto> getUsersByUser(QueryDTO query) throws UserException;
	/**
	 * 用户初始化推送（勿乱调）
	 * @throws UserException
	 */
	public void initializationUserPush() throws UserException;

	public List<UserDto> getAllUserByOrg(String orgid) throws UserException;

	/**
	 * 修改idm密码
	 * @param userId
	 * @param oldPassword
	 * @param newPassword
	 * @throws UserException
	 */
	public SaveResultDTO changePassword(String userId, String oldPassword,
			String newPassword) throws UserException;

	/**
	 * 根据用户id判断用户是否是超级管理员
	 * @param userid
	 * @return
	 */
	public int judgeAdminByUserId(String userid);

	/**
	 * 批量重置密码
	 * @param list
	 * @throws UserException
	 */
	public void resetPassword(List<String> list) throws UserException;

	/*
	 * 批量启用用户/暂停用户
	 * @param userDto
	 * @throws UserException
	 */
	public BaseResult<UserDto> batchForbidden(UserDto userDto) throws UserException;

	/**
	 * 根据手机号码保存密码
	 * @param map
	 */
	public SaveResultDTO modifyPasswordByPhone(Map<String, String> map);

	/**
	 * 根据邮箱保存密码
	 * @param map
	 */
	public SaveResultDTO modifyPasswordByEmail(Map<String, String> map);

	/**
	 * 用户的OUD推送接口
	 * @param userDto
	 * @param empuid
	 * @param iden
	 * @throws UserException
	 */
	public void callIDM(UserDto userDto,String empuid,int iden) throws UserException;

	/**
	 * 根据输入账号和系统编码查询是否有该账户未映射信息
	 * @param account
	 * @param syscode
	 * @return
	 * @throws UserException
	 */
	public AccountDispose getAccountMappingByAccAndSyscode(String account, String syscode) throws UserException;

	public boolean deleteAccountByAccAndSyscode(String account, String syscode);

	public void pushDataIDMSeven(UserDto userDto);

	/**
	 * 校验验证的的正确性及有效性
	 * @param account
	 * @param code
	 * @throws UserException
	 */
	public boolean validationCodeValidity(String account, String code) throws UserException;
	/**
	 * 通过手机号获取用户信息
	 * @param mobile
	 * @return
	 * @throws UserException
	 */
	public UserDto getUserByMobile(String mobile) throws UserException;

	/**
	 * 分页查询
	 * @param query
	 * @return
	 * @throws UserException
	 */
	public PageCriteria<UserDto> queryList(QueryDTO query, String logid, int flag) throws UserException;

	/**
	 * 根据用户id获取兼岗信息并在一个String里，号隔开
	 * @param empuid
	 * @return
	 * @throws UserException
	 */
	public String getAndPostByUserid(String empuid) throws UserException;

	/**
	 * 根据用户id获取用户信息（包含主岗岗位全路径）
	 * @param userId
	 * @return
	 */
	public UserDto getUserInfo(String userId);

	/**
	 * 获取全量岗位信息
	 * @return
	 */
	public List<OrganizationDto> getPostInfo();
	/**
	 * 禁用用户
	 * @param userid
	 * @return
	 * @throws UserException
	 */
	public void disableAccount(String userid) throws UserException;
	
	/**
	 * 启用用户
	 * @param userid
	 * @return
	 * @throws UserException
	 */
	public void enableAccount(String userid) throws UserException;
	
	/**
	 * 根据工号查询用户
	 * @param empid
	 * @return
	 */
	public User getUserByEmpid(String empid);
	
	public String getEmpuidByEmpid(String empid);
	/**
	 * 更新用户信息
	 * @param userDto
	 * @return
	 * @throws UserException
	 */
	public BaseResult<UserDto> update(UserDto userDto) throws UserException;
	/**
	 * 更新用户信息到ldap
	 * @param userDto
	 * @return
	 * @throws UserException
	 */
	public boolean  updateToLdap(UserDto userDto,Map<String, String> map) throws UserException;
	/**
	 * 保存用户信息到ldap
	 * @param userDto
	 * @return
	 * @throws UserException
	 */
	public boolean saveToLdap(UserDto userDto,Map<String, String> map , String password) throws UserException;

	/**
	 * 修改密码-根据验证码
	 * @param passwordInfoDto
	 * @return
	 * @throws UserException
	 */
	public boolean modifyPasswordByVerificationCode(PasswordInfoDto passwordInfoDto) throws BasException;
	/**
	 * 根据老密码修改密码
	 * @param passwordInfoDto
	 * @return
	 * @throws UserException
	 */
	public boolean modifyPasswordByOldPassword(PasswordInfoDto passwordInfoDto) throws BasException;
	/**
	 * 验证用户名和密码
	 * @param loginVerificationDto
	 * @return
	 * @throws BasException
	 */
	public boolean loginVerification(LoginVerificationDto loginVerificationDto) throws BasException;

	public BaseResult<UsersDto> saveUser(UsersDto userDto) throws UserException;
	public BaseResult<UsersDto> getUser(String id) throws BasException;


	/**
	 * 同步用户到BPM
	 * @param userToBpmDto
	 * @return int
	 * @throws BasException
	 */
	public boolean saveUserToBpm(UserToBpmDto userToBpmDto) throws BasException;


	/**
	 * 分页查询
	 * @param innerUserPageDto
	 * @return
	 */
	PageInfo<InnerUserDto> selectPage(InnerUserPageDto innerUserPageDto);
}
